# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetInternetGatewayResult:
    """
    A collection of values returned by getInternetGateway.
    """
    def __init__(__self__, attachments=None, filters=None, internet_gateway_id=None, owner_id=None, tags=None, id=None):
        if attachments and not isinstance(attachments, list):
            raise TypeError("Expected argument 'attachments' to be a list")
        __self__.attachments = attachments
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        __self__.filters = filters
        if internet_gateway_id and not isinstance(internet_gateway_id, str):
            raise TypeError("Expected argument 'internet_gateway_id' to be a str")
        __self__.internet_gateway_id = internet_gateway_id
        if owner_id and not isinstance(owner_id, str):
            raise TypeError("Expected argument 'owner_id' to be a str")
        __self__.owner_id = owner_id
        """
        The ID of the AWS account that owns the internet gateway.
        """
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetInternetGatewayResult(GetInternetGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInternetGatewayResult(
            attachments=self.attachments,
            filters=self.filters,
            internet_gateway_id=self.internet_gateway_id,
            owner_id=self.owner_id,
            tags=self.tags,
            id=self.id)

def get_internet_gateway(filters=None,internet_gateway_id=None,tags=None,opts=None):
    """
    `ec2.InternetGateway` provides details about a specific Internet Gateway.
    
    :param list filters: Custom filter block as described below.
    :param str internet_gateway_id: The id of the specific Internet Gateway to retrieve.
    :param dict tags: A mapping of tags, each pair of which must exactly match
           a pair on the desired Internet Gateway.
    
    The **filters** object supports the following:
    
      * `name` (`str`) - The name of the field to filter by, as defined by
        [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInternetGateways.html).
      * `values` (`list`) - Set of values that are accepted for the given field.
        An Internet Gateway will be selected if any one of the given values matches.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-aws/blob/master/website/docs/d/internet_gateway.html.markdown.
    """
    __args__ = dict()

    __args__['filters'] = filters
    __args__['internetGatewayId'] = internet_gateway_id
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:ec2/getInternetGateway:getInternetGateway', __args__, opts=opts).value

    return AwaitableGetInternetGatewayResult(
        attachments=__ret__.get('attachments'),
        filters=__ret__.get('filters'),
        internet_gateway_id=__ret__.get('internetGatewayId'),
        owner_id=__ret__.get('ownerId'),
        tags=__ret__.get('tags'),
        id=__ret__.get('id'))
